Module data

Module data 

Structs

JaggedMatrix
A jagged column aligned matrix, that owns it’s data contents.
Matrix
Contigious Column major matrix data container. This is used throughout the crate, to house both the user provided data as well as the binned data.
RowMajorMatrix
A lightweight row major matrix, this is primarily for returning data to the user, it is especially suited for appending rows to, such as when building up a matrix of data to return to the user, the added benefit is it will be even faster to return to numpy.

Traits

FloatData
Data trait used throughout the package to control for floating point numbers.