pub struct JaggedMatrix<T> {
    pub data: Vec<T>,
    pub ends: Vec<usize>,
    pub cols: usize,
    pub n_records: usize,
}
A jagged column aligned matrix, that owns it’s data contents.

Fields

data: Vec<T>

The contents of the matrix.

ends: Vec<usize>

The end index’s of the matrix.

cols: usize

Number of columns in the matrix

n_records: usize

The number of elements in the matrix.

Implementations

source

impl<T> JaggedMatrix<T>where T: Copy,

source

pub fn from_vecs(vecs: &[Vec<T>]) -> Self

Generate a jagged array from a vector of vectors

source

impl<T> JaggedMatrix<T>

source

pub fn new() -> Self

Create a new jagged matrix.

source

pub fn get_col(&self, col: usize) -> &[T]

Get the column of a jagged array.

source

pub fn get_col_mut(&mut self, col: usize) -> &mut [T]

Get a mutable reference to a column of the array.