pub enum ImportanceMethod {
Weight,
Gain,
Cover,
TotalGain,
TotalCover,
}Expand description
Method to calculate variable importance.
Variants
Weight
The number of times a feature is used to split the data across all trees.
Gain
The average split gain across all splits the feature is used in.
Cover
The average coverage across all splits the feature is used in.
TotalGain
The total gain across all splits the feature is used in.
TotalCover
The total coverage across all splits the feature is used in.