pub struct MissingBranchSplitter {
pub l1: f32,
pub l2: f32,
pub max_delta_step: f32,
pub gamma: f32,
pub min_leaf_weight: f32,
pub learning_rate: f32,
pub allow_missing_splits: bool,
pub constraints_map: ConstraintMap,
pub terminate_missing_features: HashSet<usize>,
pub missing_node_treatment: MissingNodeTreatment,
pub force_children_to_bound_parent: bool,
}Expand description
Missing branch splitter Always creates a separate branch for the missing values of a feature. This results, in every node having a specific “missing”, direction. If this node is able, it will be split further, otherwise it will a leaf node will be generated.
Fields
l1: f32l2: f32max_delta_step: f32gamma: f32min_leaf_weight: f32learning_rate: f32allow_missing_splits: boolconstraints_map: ConstraintMapterminate_missing_features: HashSet<usize>missing_node_treatment: MissingNodeTreatmentforce_children_to_bound_parent: boolImplementations
Sourceimpl MissingBranchSplitter
impl MissingBranchSplitter
pub fn new_leaves_added(&self) -> usize
pub fn update_average_missing_nodes(tree: &mut Tree, node_idx: usize) -> f64