MissingImputerSplitter

Struct MissingImputerSplitter 

pub struct MissingImputerSplitter {
    pub l1: f32,
    pub l2: f32,
    pub max_delta_step: f32,
    pub gamma: f32,
    pub min_leaf_weight: f32,
    pub learning_rate: f32,
    pub allow_missing_splits: bool,
    pub constraints_map: ConstraintMap,
}
Missing imputer splitter Splitter that imputes missing values, by sending them down either the right or left branch, depending on which results in a higher increase in gain.

Fields

l1: f32l2: f32max_delta_step: f32gamma: f32min_leaf_weight: f32learning_rate: f32allow_missing_splits: boolconstraints_map: ConstraintMap

Implementations

Source

impl MissingImputerSplitter

pub fn new( l1: f32, l2: f32, max_delta_step: f32, gamma: f32, min_leaf_weight: f32, learning_rate: f32, allow_missing_splits: bool, constraints_map: ConstraintMap, ) -> Self

Generate a new missing imputer splitter object.