map_bin

Function map_bin 

pub fn map_bin<T: FloatData<T>>(x: &[T], v: &T, missing: &T) -> Option<u16>
Return the index of the first value in a sorted vector that is greater than a provided value.

  • x - The sorted slice of values.
  • v - The value used to calculate the first value larger than it.