weight

Function weight 

pub fn weight(
    l1: &f32,
    l2: &f32,
    max_delta_step: &f32,
    gradient_sum: f32,
    hessian_sum: f32,
) -> f32
Calculate the weight of a given node, given the sum of the gradients, and the hessians in a node.