A lightweight row major matrix, this is primarily
for returning data to the user, it is especially
suited for appending rows to, such as when building
up a matrix of data to return to the
user, the added benefit is it will be even
faster to return to numpy.