Structs

A jagged column aligned matrix, that owns it’s data contents.

Contigious Column major matrix data container. This is used throughout the crate, to house both the user provided data as well as the binned data.

Traits

Data trait used throughout the package to control for floating point numbers.