pub struct Matrix<'a, T> {
pub data: &'a [T],
pub index: Vec<usize>,
pub rows: usize,
pub cols: usize,
/* private fields */
}Expand description
Contigious Column major matrix data container. This is used throughout the crate, to house both the user provided data as well as the binned data.
Fields
data: &'a [T]index: Vec<usize>rows: usizecols: usizeImplementations
sourceimpl<'a, T> Matrix<'a, T>
impl<'a, T> Matrix<'a, T>
pub fn new(data: &'a [T], rows: usize, cols: usize) -> Self
sourcepub fn get(&self, i: usize, j: usize) -> &T
pub fn get(&self, i: usize, j: usize) -> &T
Get a single reference to an item in the matrix.
i- The ith row of the data to get.j- the jth column of the data to get.
sourcepub fn get_row_iter(&self, row: usize) -> StepBy<Skip<Iter<'_, T>>>
pub fn get_row_iter(&self, row: usize) -> StepBy<Skip<Iter<'_, T>>>
Get access to a row of the data, as an iterator.