pub struct Matrix<'a, T> {
    pub data: &'a [T],
    pub index: Vec<usize>,
    pub rows: usize,
    pub cols: usize,
    /* private fields */
}
Contigious Column major matrix data container. This is used throughout the crate, to house both the user provided data as well as the binned data.

Fields

data: &'a [T]index: Vec<usize>rows: usizecols: usize

Implementations

Get a single reference to an item in the matrix.

  • i - The ith row of the data to get.
  • j - the jth column of the data to get.

Get a slice of a column in the matrix.

  • col - The index of the column to select.
  • start_row - The index of the start of the slice.
  • end_row - The index of the end of the slice of the column to select.

Get an entire column in the matrix.

  • col - The index of the column to get.