pub struct RowMajorMatrix<T> {
pub data: Vec<T>,
pub rows: usize,
pub cols: usize,
/* private fields */
}Expand description
A lightweight row major matrix, this is primarily for returning data to the user, it is especially suited for appending rows to, such as when building up a matrix of data to return to the user, the added benefit is it will be even faster to return to numpy.
Fields
data: Vec<T>rows: usizecols: usizeImplementations
Sourceimpl<T> RowMajorMatrix<T>
impl<T> RowMajorMatrix<T>
pub fn new(data: Vec<T>, rows: usize, cols: usize) -> Self
Sourcepub fn get(&self, i: usize, j: usize) -> &T
pub fn get(&self, i: usize, j: usize) -> &T
Get a single reference to an item in the matrix.
i- The ith row of the data to get.j- the jth column of the data to get.
Sourcepub fn append_row(&mut self, items: Vec<T>)
pub fn append_row(&mut self, items: Vec<T>)
Add a rows to the matrix, this can be multiple rows, if they are in sequential order in the items.