pub struct MissingBranchSplitter {
    pub l2: f32,
    pub gamma: f32,
    pub min_leaf_weight: f32,
    pub learning_rate: f32,
    pub allow_missing_splits: bool,
    pub constraints_map: ConstraintMap,
}
Missing branch splitter Always creates a separate branch for the missing values of a feature. This results, in every node having a specific “missing”, direction. If this node is able, it will be split further, otherwise it will a leaf node will be generated.

Fields

l2: f32gamma: f32min_leaf_weight: f32learning_rate: f32allow_missing_splits: boolconstraints_map: ConstraintMap