pub fn map_bin<T: PartialOrd>(x: &[T], v: &T) -> Option<u16>Expand description
Return the index of the first value in a sorted vector that is greater than a provided value.
x- The sorted slice of values.v- The value used to calculate the first value larger than it.